==> react-native-ui-view-0.1.1.tgz: package/esm/components/Picker/index.js <==
import React, { useRef } from 'react';
import { StyleSheet, View, Text } from 'react-native';
import Popup from '../Popup';
import { Theme } from '../Styles/theme';
import Touchable from '../Touchable';
import PickerView from './pickerView';
const Picker = props => {
    const { visible = false, barStyle = 'dark-content', dataSource, selectedIndex, itemHeight = 40, showToolbar = true, title, cancelText = '取消', cancelColor, confirmText = '确定', confirmColor, closeOnClickOverlay = false, onClose, onChange, onConfirm, } = props;
    const indexList = useRef(selectedIndex);
    return (React.createElement(Popup, { visible: visible, barStyle: barStyle, closeOnClickOverlay: closeOnClickOverlay, onClose: onClose },
        React.createElement(View, { style: styles.container },
            showToolbar && (React.createElement(View, { style: styles.toolbar },
                React.createElement(Touchable, { onPress: onClose },
                    React.createElement(Text, { style: [styles.toolbarText, cancelColor ? { color: cancelColor } : {}] }, cancelText)),
                !!title && React.createElement(Text, { style: styles.toolbarText }, title),
                React.createElement(Touchable, { onPress: () => {
                        onConfirm && onConfirm(indexList.current);
                        onClose && onClose();
                    } },
                    React.createElement(Text, { style: [styles.toolbarText, styles.confirmText, confirmColor ? { color: confirmColor } : {}] }, confirmText)))),
            React.createElement(PickerView, { dataSource: dataSource, selectedIndex: selectedIndex, itemHeight: itemHeight, onChange: data => {
                    indexList.current = data;
                    onChange && onChange(data);
                } }))));
};
const styles = StyleSheet.create({
    container: {
        backgroundColor: '#fff',
    },
    toolbar: {
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'center',
        paddingHorizontal: Theme.hSpacingLg,
        paddingVertical: Theme.vSpacingMd,
    },
    toolbarText: {
        fontSize: Theme.fontSizeCaption,
        color: Theme.colorTextGray,
    },
    confirmText: {
        color: Theme.brandPrimaryTap,
    },
});
export default Picker;

==> react-native-ui-view-0.2.0.tgz: package/esm/components/Picker/index.js <==
import React, { useEffect, useState } from 'react';
import { StyleSheet, View, Text } from 'react-native';
import Popup from '../Popup';
import { Theme } from '../Styles/theme';
import Touchable from '../Touchable';
import PickerView from './pickerView';
const Picker = props => {
    const { visible = false, barStyle = 'dark-content', dataSource, selectedIndex, itemHeight = 40, showToolbar = true, title, cancelText = '取消', cancelColor, confirmText = '确定', confirmColor, closeOnClickOverlay = false, onClose, onChange, onConfirm, } = props;
    const [indexList, setIndexList] = useState([...selectedIndex]);
    useEffect(() => {
        setIndexList([...selectedIndex]);
    }, [selectedIndex]);
    return (React.createElement(Popup, { visible: visible, barStyle: barStyle, closeOnClickOverlay: closeOnClickOverlay, onClose: onClose },
        React.createElement(View, { style: styles.container },
            showToolbar && (React.createElement(View, { style: styles.toolbar },
                React.createElement(Touchable, { onPress: onClose },
                    React.createElement(Text, { style: [styles.toolbarText, cancelColor ? { color: cancelColor } : {}] }, cancelText)),
                !!title && React.createElement(Text, { style: styles.toolbarText }, title),
                React.createElement(Touchable, { onPress: () => {
                        onConfirm && onConfirm(indexList);
                        onClose && onClose();
                    } },
                    React.createElement(Text, { style: [styles.toolbarText, styles.confirmText, confirmColor ? { color: confirmColor } : {}] }, confirmText)))),
            React.createElement(PickerView, { dataSource: dataSource, selectedIndex: indexList, itemHeight: itemHeight, onChange: data => {
                    setIndexList(data);
                    onChange && onChange(data);
                } }))));
};
const styles = StyleSheet.create({
    container: {
        backgroundColor: '#fff',
    },
    toolbar: {
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'center',
        paddingHorizontal: Theme.hSpacingLg,
        paddingVertical: Theme.vSpacingMd,
    },
    toolbarText: {
        fontSize: Theme.fontSizeCaption,
        color: Theme.colorTextGray,
    },
    confirmText: {
        color: Theme.brandPrimaryTap,
    },
});
export default Picker;
